@@ -169,17 +169,16 @@ class AdsorbateOperator(OffspringCreator):
         i = 0
         occupied = False
         while not occupied:
-            site = hetero_site_list[i]
-            if not site['occupied']:
-                i += 1
-                continue
-
             if i >= len(hetero_site_list):
                 if return_site_index:
                     return False
                 warnings.warn('Removal not possible, will add instead')
                 return self.add_adsorbate(atoms, hetero_site_list, site_heights)
 
+            site = hetero_site_list[i]
+            if not site['occupied']:
+                i += 1
+                continue
             # Remove adsorbate from the correct position. Remove the fragment
             # with priority if it is one of the given adsorbate species
             rm_frag = (site['fragment'] in self.adsorbate_species) 
@@ -1059,8 +1058,8 @@ class ReplaceAdsorbateSpecies(AdsorbateOperator):
         specs = [t[0] for t in sac.get_adsorbates(self.adsorbate_species)]
         # Return None if no adsorbate is present
         if not specs:
-            return None, '{1} not possible in {0}'.format(f.info['confid'],
-                                                          self.descriptor)
+            return None, '{0} not possible in {1}'.format(self.descriptor,
+                                                          f.info['confid'])
         spec = random.choice(specs)
         all_specs = self.adsorbate_species.copy()
         if self.replace_vacancy:
