@@ -139,12 +139,12 @@ class WLGraphComparator(object):
                 A2 = a2.info['data']['adj_matrix']
                 G2 = nx.from_numpy_matrix(A2)
             else:
-                nblist1 = neighbor_shell_list(a1, dx=dx, neighbor_number=1,
-                                         mic=(True in a1.pbc))
+                nblist1 = neighbor_shell_list(a1, dx=self.dx, neighbor_number=1,
+                                              mic=(True in a1.pbc))
                 A1 = get_adj_matrix(nblist1)
                 G1 = nx.from_numpy_matrix(A1)
-                nblist2 = neighbor_shell_list(a2, dx=dx, neighbor_number=1,
-                                         mic=(True in a2.pbc))
+                nblist2 = neighbor_shell_list(a2, dx=self.dx, neighbor_number=1,
+                                              mic=(True in a2.pbc))
                 A2 = get_adj_matrix(nblist2)
                 G2 = nx.from_numpy_matrix(A2)
             s1 = a1.symbols
