@@ -358,7 +358,10 @@ class AdsorbateGroupSubstitute(Mutation):
             assert len(self.species_probabilities.keys()) == len(self.adsorbate_species) 
                                                      
         self.site_groups = site_groups
-        self.max_species = max_species
+        if max_species is None:
+            self.max_species = None
+        else:
+            self.max_species = min([max_species, len(set(self.adsorbate_species))])
         self.heights = site_heights 
         for k, v in heights.items():
             self.heights[k] = v
