@@ -382,7 +382,8 @@ class RandomCompositionMutation(SlabOperator):
                 self.descriptor + parent_message)
 
     def operate(self, atoms):
-        if self.allowed_compositions is None:
+        allowed_comps = self.allowed_compositions
+        if allowed_comps is None:
             n_elems = len(set(atoms.get_chemical_symbols()))
             n_atoms = len(atoms)
             allowed_comps = [c for c in permutations(range(1, n_atoms),
@@ -397,10 +398,10 @@ class RandomCompositionMutation(SlabOperator):
         # Choose the composition to change to
         for i, allowed in enumerate(allowed_comps):
             if comp == tuple(allowed):
+                allowed_comps = np.delete(allowed_comps, i, axis=0)
                 break
-        comps_to_choose_from = np.delete(allowed_comps, i, axis=0)
-        new_comp = random.choice(comps_to_choose_from)
-        comp_diff = self.get_composition_diff(comp, new_comp)
+        chosen = random.randint(0, len(allowed_comps) - 1)
+        comp_diff = self.get_composition_diff(comp, allowed_comps[chosen])
 
         # Get difference from current composition
         to_add, to_rem = get_add_remove_lists(
