@@ -13,7 +13,7 @@ import os
 class WL(object):
 
     def __init__(self,
-                 hp={'length': np.array([.75, .25]), 't': 2},
+                 hp={'length': np.array([.75, .25])},
                  normalize=False,
                  atom_wise=True,
                  dx=0.5,
@@ -78,7 +78,7 @@ class WL(object):
 #                d.update((k, 0) for k in all_keys - old_keys)
             dicts = np.asarray(dicts, dtype=object)
             if get_dists:
-                t = self.hp['t']                                                    
+                t = len(self.hp['length'])                                                  
                 Kdts = [np.zeros(shape=(len(dicts), len(dicts)))] * t
                 idx0dt, idx1dt = np.triu_indices_from(Kdts[0])
                 for idt in range(len(idx0dt)):
@@ -148,11 +148,7 @@ class WL(object):
                               full_effect=True, connect_dentates=True)                  
         G = nx.from_numpy_matrix(A)
 
-        if 't' in self.hp:
-            t = self.hp['t']
-        else:
-            t = 2
-
+        t = len(self.hp['length'])
         nnlabs, neighbors, lpd = {}, {}, {}
         isolates = []
         for i in range(len(A)):
@@ -251,7 +247,7 @@ class WL(object):
                 pool = Pool(self.n_jobs)
                 dicts = pool.map(self.get_dict, train_images)
                 dicts = np.asarray(dicts, dtype=object)
-                t = self.hp['t']                                                     
+                t = len(self.hp['length'])                                                   
                 Kdts = [np.zeros(shape=(len(dicts), len(dicts)))] * t
                 idx0dt, idx1dt = np.triu_indices_from(Kdt)
                 for idt in range(len(idx0dt)):
